import { InjectionToken, Injectable, Inject, NgModule } from '@angular/core';
import { Location, CommonModule } from '@angular/common';
import { fromEvent } from 'rxjs';
import { Router } from '@angular/router';
import { map, filter } from 'rxjs/operators';

const MICRO_APP_NAME = new InjectionToken('microAppName');
const ROUTE_CHANGE_EVENT_NAME = new InjectionToken('routeChangeEventName');
class AngularElementRoutingService {
    constructor(microApp, routeChangeEvent, router, location) {
        this.microApp = microApp;
        this.router = router;
        this.location = location;
        this.routeChange$ = fromEvent(document, routeChangeEvent).pipe(map((event) => event.detail.route), filter((event) => event.app === this.microApp));
    }
    initRouting() {
        this.routeChange$.subscribe((event) => {
            this.router.navigateByUrl(`${event.path}`);
        });
        this.router.navigateByUrl(this.location.path(true));
    }
}
AngularElementRoutingService.decorators = [
    { type: Injectable }
];
AngularElementRoutingService.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [MICRO_APP_NAME,] }] },
    { type: undefined, decorators: [{ type: Inject, args: [ROUTE_CHANGE_EVENT_NAME,] }] },
    { type: Router },
    { type: Location }
];

class AngularElementRouteModule {
    constructor(microRoutingService) {
        this.microRoutingService = microRoutingService;
        microRoutingService.initRouting();
    }
    static forRoot(microElementApplication, routeChangeEventName) {
        return {
            ngModule: AngularElementRouteModule,
            providers: [
                AngularElementRoutingService,
                { provide: MICRO_APP_NAME, useValue: microElementApplication },
                { provide: ROUTE_CHANGE_EVENT_NAME, useValue: routeChangeEventName },
            ],
        };
    }
}
AngularElementRouteModule.decorators = [
    { type: NgModule, args: [{
                declarations: [],
                imports: [CommonModule],
            },] }
];
AngularElementRouteModule.ctorParameters = () => [
    { type: AngularElementRoutingService }
];

/*
 * Public API Surface of angular-element-routing
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AngularElementRouteModule, MICRO_APP_NAME as ɵa, ROUTE_CHANGE_EVENT_NAME as ɵb, AngularElementRoutingService as ɵc };
//# sourceMappingURL=microfrontendly-angular-element-routing.js.map
